<?php

if (!current_user_can('manage_options')) {
    die('The account you\'re logged in to doesn\'t have permission to access this page.');
}

function fbrev_has_valid_nonce() {
    $nonce_actions = array('fbrev_settings', 'fbrev_active');
    $nonce_form_prefix = 'fbrev-form_nonce_';
    $nonce_action_prefix = 'fbrev-wpnonce_';
    foreach ($nonce_actions as $key => $value) {
        if (isset($_POST[$nonce_form_prefix.$value])) {
            check_admin_referer($nonce_action_prefix.$value, $nonce_form_prefix.$value);
            return true;
        }
    }
    return false;
}

if (!empty($_POST)) {
    $nonce_result_check = fbrev_has_valid_nonce();
    if ($nonce_result_check === false) {
        die('Unable to save changes. Make sure you are accessing this page from the Wordpress dashboard.');
    }
}

// Post fields that require verification.
$valid_fields = array(
    'fbrev_active' => array(
        'key_name' => 'fbrev_active',
        'values' => array('Disable', 'Enable')
    ));

// Check POST fields and remove bad input.
foreach ($valid_fields as $key) {

    if (isset($_POST[$key['key_name']]) ) {

        // SANITIZE first
        $_POST[$key['key_name']] = trim(sanitize_text_field($_POST[$key['key_name']]));

        // Validate
        if (isset($key['regexp']) && $key['regexp']) {
            if (!preg_match($key['regexp'], $_POST[$key['key_name']])) {
                unset($_POST[$key['key_name']]);
            }

        } else if (isset($key['type']) && $key['type'] == 'int') {
            if (!intval($_POST[$key['key_name']])) {
                unset($_POST[$key['key_name']]);
            }

        } else {
            $valid = false;
            $vals = $key['values'];
            foreach ($vals as $val) {
                if ($_POST[$key['key_name']] == $val) {
                    $valid = true;
                }
            }
            if (!$valid) {
                unset($_POST[$key['key_name']]);
            }
        }
    }
}

if (isset($_POST['fbrev_active']) && isset($_GET['fbrev_active'])) {
    update_option('fbrev_active', ($_GET['fbrev_active'] == '1' ? '1' : '0'));
}

if (isset($_POST['fbrev_setting'])) {
    update_option('fbrev_app_id', $_POST['fbrev_app_id']);
    update_option('fbrev_app_secret', $_POST['fbrev_app_secret']);
}

wp_register_style('twitter_bootstrap3_css', plugins_url('/static/css/bootstrap.min.css', __FILE__));
wp_enqueue_style('twitter_bootstrap3_css', plugins_url('/static/css/bootstrap.min.css', __FILE__));

wp_register_style('rplg_setting_css', plugins_url('/static/css/rplg-setting.css', __FILE__));
wp_enqueue_style('rplg_setting_css', plugins_url('/static/css/rplg-setting.css', __FILE__));

wp_enqueue_script('jquery');

$fbrev_app_id = get_option('fbrev_app_id');
$fbrev_app_secret = get_option('fbrev_app_secret');
$fbrev_enabled = get_option('fbrev_active') == '1';
?>

<span class="rplg-version"><?php echo fbrev_i('Free Version: %s', esc_html(FBREV_VERSION)); ?></span>
<div class="rplg-setting container-fluid">
    <div class="rplg-setting-facebook">MSC FB Reviews</div>
    <ul class="nav nav-tabs" role="tablist">
        <li role="presentation" class="active">
            <a href="#about" aria-controls="about" role="tab" data-toggle="tab"><?php echo fbrev_i('About'); ?></a>
        </li>
        <li role="presentation">
            <a href="#setting" aria-controls="setting" role="tab" data-toggle="tab"><?php echo fbrev_i('Setting'); ?></a>
        </li>
        
    </ul>
    <div class="tab-content">
        <div role="tabpanel" class="tab-pane active" id="about">
            <div class="row">
                <div class="col-sm-6">
                    <h4><?php echo fbrev_i('MSC FB Reviews Widget for WordPress'); ?></h4>
                    <p><?php echo fbrev_i('MSC FB Reviews plugin is an easy and fast way to integrate Facebook business reviews right into your WordPress website. This plugin works instantly and show FB Reviews in sidebar widget.'); ?></p>
                    <ol>
                        <li>Go to menu <b>"Appearance"</b> -> <b>"Widgets"</b></li>
                        <li>Move "FB Reviews" widget to sidebar</li>
                        <li>Click by 'Connect to Facebook' button</li>
                        <li>Log in via Facebook and agree manage pages permission</li>
                        <li>After log in under the button you will see a list of your Facebook pages</li>
                        <li>Click on the needed page and <b>Save</b> the widget</li>
                    </ol>
                    <p><?php echo fbrev_i('Feel free to contact me by email <a href="mailto:me@jaras.uk">me@jaras.uk</a>.'); ?></p>
                    <div class="row">
                        <div class="col-sm-4">
                            
                            <div class="fb-like" data-href="https://#MSC/" data-layout="button_count" data-action="like" data-show-faces="true" data-share="false"></div>
                        </div>
             
                        
                    </div>
                </div>
                <div class="col-sm-6">
                    <br>
                    
                </div>
            </div>
            <hr>
            
        </div>
        <div role="tabpanel" class="tab-pane" id="setting">
            <h4><?php echo fbrev_i('MSC FB Reviews Widget Setting'); ?></h4>
           
           
           
           
           
            <!-- Configuration form -->
            
            
            
            
            
            <form method="POST" enctype="multipart/form-data">
                <?php wp_nonce_field('fbrev-wpnonce_fbrev_settings', 'fbrev-form_nonce_fbrev_settings'); ?>
                <div class="form-group">
                    <label class="control-label" for="fbrev_app_id"><?php echo fbrev_i('App ID'); ?></label>
                    <input class="form-control" type="text" id="fbrev_app_id" name="fbrev_app_id" value="<?php echo esc_attr($fbrev_app_id); ?>">
                </div>
                <div class="form-group">
                    <label class="control-label" for="fbrev_app_secret"><?php echo fbrev_i('App Secret'); ?></label>
                    <input class="form-control" type="text" id="fbrev_app_secret" name="fbrev_app_secret" value="<?php echo esc_attr($fbrev_app_secret); ?>">
                </div>
                <div class="form-group">
                    <b>To get Facebook 'App ID' and 'App Secret', please make following steps:</b><br>
                    1. Go to <a href="https://developers.facebook.com/apps" target="_blank">Facebook for Developers</a><br>
                    2. Click '<b>+ Add a New App</b>'<br>
                    3. Enter any '<b>Display Name</b>' and click '<b>Create App ID</b>'<br>
                    4. On the '<b>Facebook Login</b>' panel click '<b>Set Up</b>' button<br>
                    5. Select '<b>WWW</b>' (Web) platform<br>
                    6. In the menu go to <b>'Facebook Login' / 'Settings'</b><br>
                    7. In the '<b>Valid OAuth Redirect URIs</b>' field, please enter <b>https://app.widgetpack.com/auth/fbrev/callback</b> and click '<b>Save Changes</b>'<br>
                    8. In the menu go to <b>'Settings' / 'Basic'</b> and copy & paste 'App ID' and 'App Secret' keys to the plugin's setting and Save.
                </div>
                <p class="submit" style="text-align: left">
                    <input name="fbrev_setting" type="submit" value="Save" class="button-primary button" tabindex="4">
                </p>
            </form>
            
            
            
            <!-- Enable/disable MSC FB Reviews Widget toggle -->
            <form method="POST" action="?page=fbrev&amp;fbrev_active=<?php echo (string)((int)($fbrev_enabled != true)); ?>">
                <?php wp_nonce_field('fbrev-wpnonce_fbrev_active', 'fbrev-form_nonce_fbrev_active'); ?>
                <span class="status">
                    <?php echo fbrev_i('MSC FB Reviews Widget are currently '). ($fbrev_enabled ? '<b>' . fbrev_i('enable') . '</b>' : '<b>' . fbrev_i('disable') . '</b>'); ?>
                </span>
                <input type="submit" name="fbrev_active" class="button" value="<?php echo $fbrev_enabled ? fbrev_i('Disable') : fbrev_i('Enable'); ?>" />
            </form>
            <hr>
            <button class="btn btn-primary btn-small" type="button" data-toggle="collapse" data-target="#debug" aria-expanded="false" aria-controls="debug">
                <?php echo fbrev_i('Debug Information'); ?>
            </button>
            <div id="debug" class="collapse">
                <textarea style="width:90%; height:200px;" onclick="this.select();return false;" readonly><?php
                    rplg_debug(FBREV_VERSION, fbrev_options(), 'widget_fbrev_widget');
                ?></textarea>
            </div>
            <div style="max-width:700px"></div>
        </div>
        
    </div>
</div>
<script type="text/javascript">
jQuery(document).ready(function($) {
    $('a[data-toggle="tab"]').on('click', function(e)  {
        var active = $(this).attr('href');
        $('.tab-content ' + active).addClass('active').show().siblings().hide();
        $(this).parent('li').addClass('active').siblings().removeClass('active');
        e.preventDefault();
    });
    $('button[data-toggle="collapse"]').click(function () {
        $target = $(this);
        $collapse = $target.next();
        $collapse.slideToggle(500);
    });
});
</script>